/*****************************************************************************************
*                                                                                        *
* This SAS program will extract the United States Sentencing Commission's 21 U.S.C.  851*
* Enhanced Drug Penalty Fiscal Year 2022 file and create a SAS dataset.                  *
*                                                                                        *
* Prior to running the program you must update the DAT file location in the FILNAME line *
* to correspond to the location of the file on your computer.                            *
*                                                                                        *
* You must also update the library location in the LIBNAME statement to correspond to    *
* the folder you want the output file to be located.                                     *
*                                                                                        *
*****************************************************************************************/

/* The following line should contain the complete path and name of your raw data file */
FILENAME datafile '.\drug851fy22nid.dat' ;

/* The following line should contain the directory in which you wish your SAS file to be stored */
libname library '.' ;

/* The following line contains the name (without the extension) for your SAS dataset */
%LET dataset = drug851fy22nid ;

DATA library.&dataset ;
INFILE datafile LRECL=417;
INPUT
   USSCIDN  1-7             STMIN851  8-11           STMAX851  12-15       
   DGMIN851  16-19          DGMAX851  20-23          FILED  24             
   WITHDRWN  25             RELIEF  26               CTRELIEF  27          
   CRMHT851  28             INDTDATE DATE11.         FILEDATE DATE11.      
   PROFFN1  51-53           PROFFN2  54-56           PROFFN3  57-59        
   PROFFN4  60-62           PROFFN5  63-65           PROFFN6  66-68        
   PROFFN7  69-71           PROFFN8  72-74           PROFFN9  75-77        
   PROFFN10  78-80          PROFFN11  81-83          PROFFN12  84-86       
   PROFFN13  87-89          PROFFN14  90-92          PROFFN15  93-95       
   PROFFN16  96-98          PROFFN17  99-101         PROFFN18  102-104     
   PROFFN19  105-107        PRSENT1  108-111         PRSENT2  112-115      
   PRSENT3  116-118         PRSENT4  119-122         PRSENT5  123-125      
   PRSENT6  126-128         PRSENT7  129-132         PRSENT8  133-136      
   PRSENT9  137-140         PRSENT10  141-144        PRSENT11  145-148     
   PRSENT12  149-150        PRSENT13  151-152        PRSENT14  153-154     
   PRSENT15  155-156        PRSENT16  157-160        PRSENT17  161-163     
   PRSENT18  164-166        PRSENT19  167-168        PRSNDT1 DATE11.       
   PRSNDT2 DATE11.          PRSNDT3 DATE11.          PRSNDT4 DATE11.       
   PRSNDT5 DATE11.          PRSNDT6 DATE11.          PRSNDT7 DATE11.       
   PRSNDT8 DATE11.          PRSNDT9 DATE11.          PRSNDT10 DATE11.      
   PRSNDT11 DATE11.         PRSNDT12 DATE11.         PRSNDT13 DATE11.      
   PRSNDT14 DATE11.         PRSNDT15 DATE11.         PRSNDT16 DATE11.      
   PRSNDT17 DATE11.         PRSNDT18 DATE11.         PRSNDT19 DATE11.      
   OFFENNUM  378-379        PRCHPT1  380             PRCHPT2  381          
   PRCHPT3  382             PRCHPT4  383             PRCHPT5  384          
   PRCHPT6  385             PRCHPT7  386             PRCHPT8  387          
   PRCHPT9  388             PRCHPT10  389            PRCHPT11  390         
   PRCHPT12  391            PRCHPT13  392            PRCHPT14  393         
   PRCHPT15  394            PRCHPT16  395            PRCHPT17  396         
   PRCHPT18  397            PRCHPT19  398            PRFELN1  399          
   PRFELN2  400             PRFELN3  401             PRFELN4  402          
   PRFELN5  403             PRFELN6  404             PRFELN7  405          
   PRFELN8  406             PRFELN9  407             PRFELN10  408         
   PRFELN11  409            PRFELN12  410            PRFELN13  411         
   PRFELN14  412            PRFELN15  413            PRFELN16  414         
   PRFELN17  415            PRFELN18  416            PRFELN19  417         
 ;                       

FORMAT
   INDTDATE DATE9.          FILEDATE DATE9.          PRSNDT1 DATE9.        
   PRSNDT2 DATE9.           PRSNDT3 DATE9.           PRSNDT4 DATE9.        
   PRSNDT5 DATE9.           PRSNDT6 DATE9.           PRSNDT7 DATE9.        
   PRSNDT8 DATE9.           PRSNDT9 DATE9.           PRSNDT10 DATE9.       
   PRSNDT11 DATE9.          PRSNDT12 DATE9.          PRSNDT13 DATE9.       
   PRSNDT14 DATE9.          PRSNDT15 DATE9.          PRSNDT16 DATE9.       
   PRSNDT17 DATE9.          PRSNDT18 DATE9.          PRSNDT19 DATE9.       
 ;
                      

LENGTH
   USSCIDN 6                STMIN851 4               STMAX851 4            
   DGMIN851 4               DGMAX851 4               FILED 3               
   WITHDRWN 3               RELIEF 3                 CTRELIEF 3            
   CRMHT851 3               PROFFN1 4                PROFFN2 4             
   PROFFN3 4                PROFFN4 4                PROFFN5 4             
   PROFFN6 4                PROFFN7 4                PROFFN8 4             
   PROFFN9 4                PROFFN10 4               PROFFN11 4            
   PROFFN12 4               PROFFN13 4               PROFFN14 4            
   PROFFN15 4               PROFFN16 4               PROFFN17 4            
   PROFFN18 4               PROFFN19 4               PRSENT1 4             
   PRSENT2 4                PRSENT3 4                PRSENT4 4             
   PRSENT5 4                PRSENT6 4                PRSENT7 4             
   PRSENT8 4                PRSENT9 4                PRSENT10 4            
   PRSENT11 4               PRSENT12 3               PRSENT13 3            
   PRSENT14 3               PRSENT15 3               PRSENT16 4            
   PRSENT17 4               PRSENT18 4               PRSENT19 3            
   OFFENNUM 3               PRCHPT1 3                PRCHPT2 3             
   PRCHPT3 3                PRCHPT4 3                PRCHPT5 3             
   PRCHPT6 3                PRCHPT7 3                PRCHPT8 3             
   PRCHPT9 3                PRCHPT10 3               PRCHPT11 3            
   PRCHPT12 3               PRCHPT13 3               PRCHPT14 3            
   PRCHPT15 3               PRCHPT16 3               PRCHPT17 3            
   PRCHPT18 3               PRCHPT19 3               PRFELN1 3             
   PRFELN2 3                PRFELN3 3                PRFELN4 3             
   PRFELN5 3                PRFELN6 3                PRFELN7 3             
   PRFELN8 3                PRFELN9 3                PRFELN10 3            
   PRFELN11 3               PRFELN12 3               PRFELN13 3            
   PRFELN14 3               PRFELN15 3               PRFELN16 3            
   PRFELN17 3               PRFELN18 3               PRFELN19 3 ;

        

RUN ;
